deep_observer library

Deep Observer

/ Library for efficient handling of reactive states in Flutter.

Description

Allows for efficient state management through a system of observables and dependencies based on BuildContext.

Author

Developed by Carlos Francisco Parra García.

License

MIT License - See the LICENSE file for more details.

© 2025 Carlos Francisco Parra García. All rights reserved.

GitHub: https://github.com/carlosparra1998?tab=repositories

LinkedIn: https://www.linkedin.com/in/carlos-francisco-parra-garcía-9b16941b5/

Classes

DeepObservable<T>
You create a new instance of the DeepObservable class. This instance will contain properties that allow you to easily manage reactivity in your code.
DeepUpdatable
This Widget DeepUpdatable will allow you to control the reactivity of your observables explicitly.
GlobalInjector<T>
This Widget GlobalInjector will allow you to create unique instances of your provider classes throughout the app.
LocalInjector<T>
This Widget LocalInjector will allow you to create unique instances of your provider class within the generated context.

Extensions

DeepContext on BuildContext
This extension DeepContext will provide methods for managing instances of the provider classes.